@@ -3,10 +3,49 @@
 # * distance matrix calculation takes time, careful with n > 1,000
 # * gower's distance of {L,A,B} looks pretty good too
 # * more control over graphical elements and par()
+# * grid size estimation needs some work
+ 
 
-## quick preview of colors, sorted by clustering of CIE LAB representation
-# grid size estimation needs some work
-previewColors <- function(cols, method='grid', col.order=NULL, nrow=ceiling(sqrt(length(cols))), ncol=nrow, border.col='black', pt.cex=2) {
+
+
+#' @title Preview Colors
+#' 
+#' @description Preview colors as a grid arranged according to CIE2000 distances.
+#'
+#' @param cols vector of R colors
+#' @param method either "grid", "MDS", or "manual", see details
+#' @param col.order integer vector used to order colors
+#' @param nrow number of rows used by "grid" method
+#' @param ncol number of columns used by "grid" method
+#' @param border.col border color used by "grid" method
+#' @param pt.cex point scaling factor used by "MDS" method
+#' @param pt.pch point symbol used by "MDS" method
+#' 
+#' @details Color sorting is based on CIE2000 distances as calculated by \code{farver::compare_colour()}. The "grid" method arranges colors in a rectangular grid with ordering based on divisive hierarchical clustering of the pair-wise distances. Unique colors are used when \code{cols} contains more than 5,000 colors.
+#' 
+#' The "MDS" method arranges unique colors via classical multidimensional scaling (principal coordinates) via \code{MASS::cmdscale}.
+#' 
+#' Colors can be manually arranged by supplying a vector of integers to \code{col.order} and setting \code{method='manual'}.
+#' 
+#' @author D.E. Beaudette
+#' 
+#' 
+#'
+#' @return When \code{method = "grid" or "manual"} a vector of color order is returned. When \code{method = "MDS"}, the output from \code{MASS::cmdscale}.
+#' @export
+#'
+#' @examples
+#' 
+#' # example data
+#' data(sp2)
+#' 
+#' # convert into SoilProfileCollection object
+#' depths(sp2) <- id ~ top + bottom
+#' 
+#' previewColors(sp2$soil_color)
+#' previewColors(sp2$soil_color, method = 'MDS', pt.cex = 3)
+#' 
+previewColors <- function(cols, method = 'grid', col.order = NULL, nrow = ceiling(sqrt(length(cols))), ncol = nrow, border.col = 'black', pt.cex = 2, pt.pch = 15) {
 
   # sanity check, need this for color distance eval
   if(!requireNamespace('farver', quietly = TRUE))
@@ -18,7 +57,9 @@ previewColors <- function(cols, method='grid', col.order=NULL, nrow=ceiling(sqrt
   # safety catch: a 5000 x 5000 element distance matrix is about all we really need for a preview
   if(length(cols) > 5000) {
     cols <- unique(cols)
-    warning('using unique colors')
+    pt.cex <- pt.cex[1]
+    pt.pch <- pt.pch
+    warning('using unique colors, and first `pt.cex` / `pt.pch')
   }
 
   # use unique colors when using MDS
@@ -55,15 +96,12 @@ previewColors <- function(cols, method='grid', col.order=NULL, nrow=ceiling(sqrt
   d <- farver::compare_colour(cols.lab, from_space='lab', to_space = 'lab', method='CIE2000')
   d <- as.dist(t(d))
 
-  # distances in CIELAB
-  # col.order <- cluster::diana(cols.lab, stand = TRUE)$order
-
   if(method == 'grid') {
     # divisive hierarchical clustering for order
     col.order <- cluster::diana(d)$order
 
     # re-order colors and convert into a matrix
-    m <- matrix(NA, nrow=nrow, ncol=ncol)
+    m <- matrix(NA, nrow = nrow, ncol = ncol)
     m[1:length(cols)] <- cols[col.order]
 
     par(mar=c(1,0,3,0))
@@ -85,8 +123,10 @@ previewColors <- function(cols, method='grid', col.order=NULL, nrow=ceiling(sqrt
     par(mar=c(1,1,3,1))
     plot(mds, type='n', axes=FALSE)
     grid(nx=10, ny=10, col=par('fg'))
-    points(mds, pch=15, col=cols, cex=pt.cex)
+    points(mds, col = cols, cex = pt.cex, pch = pt.pch)
     box()
+    
+    invisible(mds)
   }
 
 }
