@@ -8,6 +8,14 @@ sp1$soil_color <- with(sp1, munsell2rgb(hue, value, chroma))
 depths(sp1) <- id ~ top + bottom
 site(sp1) <- ~ group
 
+# additional example data
+set.seed(101010)
+p <- lapply(letters[1:10], random_profile, method = 'LPP', SPC = TRUE)
+p <- combine(p)
+
+# make a factor style hz attr
+p$p.factor <- cut(p$p1, quantile(p$p1), include.lowest = TRUE)
+
 
 ## tests
 
@@ -33,6 +41,7 @@ test_that("plotSPC: aqp.env settings", {
   expect_equal(1:length(sp1), lsp$plot.order)
 })
 
+
 test_that("plotSPC: figure settings", {
 
   # explainer returns `lsp`
@@ -80,7 +89,6 @@ test_that("plotSPC: relative spacing", {
 
 
 
-
 test_that("plotSPC: re-ordering of profiles and relative spacing", {
 
   # new order
@@ -190,3 +198,75 @@ test_that("addVolumeFraction fractional horizon depths", {
   expect_message(addVolumeFraction(sp1, 'prop'), regexp = 'truncating')
 
 })
+
+
+test_that("horizon color specification interpreted correctly", {
+  
+  # this function works with contents of @horizons
+  h <- horizons(p)
+  
+  # colors to use
+  cols <- c("#5E4FA2", "#3288BD", "#66C2A5","#ABDDA4", "#E6F598", "#FEE08B","#FDAE61", "#F46D43", "#D53E4F","#9E0142")
+  
+  # attempt to interpret
+  x <- aqp:::.interpretHorizonColor(
+    h, 
+    color = 'p1', 
+    default.color = 'grey', 
+    col.palette = cols,
+    col.palette.bias = 1,
+    n.legend = 8
+    )
+  
+  # reasonable object?
+  expect_true(inherits(x, 'list'))
+  expect_true(length(x) == 2)
+  expect_true(length(x$color.legend.data) == 4)
+  expect_false(x$color.legend.data$multi.row.legend)
+  expect_null(x$color.legend.data$leg.row.indices)
+  
+  # another try, no colors specified
+  x <- aqp:::.interpretHorizonColor(
+    h, 
+    color = NA, 
+    default.color = 'grey', 
+    col.palette = cols,
+    col.palette.bias = 1,
+    n.legend = 8
+  )
+  
+  # horizon colors should match default.color
+  expect_true(all(x$colors == 'grey'))
+  
+  # there is no legend
+  expect_true(is.null(x$color.legend.data))
+  
+  
+  # factor variable + multi-line legend
+  x <- aqp:::.interpretHorizonColor(
+    h, 
+    color = 'p.factor', 
+    default.color = 'grey', 
+    col.palette = cols,
+    col.palette.bias = 1,
+    n.legend = 2
+  )
+  
+  # multi-line legend details
+  expect_true(x$color.legend.data$multi.row.legend)
+  # row indices are stored in a list
+  expect_true(inherits(x$color.legend.data$leg.row.indices, 'list'))
+  # there should be two rows
+  expect_true(length(x$color.legend.data$leg.row.indices) == 2)
+  # legend item indices are stored by row 
+  expect_equal(x$color.legend.data$leg.row.indices[[1]], c(1,2))
+  expect_equal(x$color.legend.data$leg.row.indices[[2]], c(3,4))
+  
+})
+
+
+
+
+
+
+
